
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef velodyne_MSG_LIB_H
#define velodyne_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "velodyneType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  VELODYNE_MBOX_NAME                  genomInstanceName("velodyne")

#define  VELODYNE_MAX_RQST_SIZE              272

#define  VELODYNE_MBOX_RQST_SIZE       \
 (BUF_SIZE(VELODYNE_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  VELODYNE_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  VELODYNE_MAX_REPLY_SIZE             272

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  VELODYNE_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(VELODYNE_MAX_REPLY_SIZE) \
   + BUF_SIZE(VELODYNE_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define VELODYNE_INIT_RQST 0
#define VELODYNE_GETINITPARAMS_RQST 1
#define VELODYNE_SETREADMODEPARAMS_RQST 2
#define VELODYNE_GETREADMODEPARAMS_RQST 3
#define VELODYNE_SETSENSORTOMAINPLAYBACK_RQST 4
#define VELODYNE_FOVREMOVEHEADINGSECTOR_RQST 5
#define VELODYNE_FOVREMOVELINE_RQST 6
#define VELODYNE_STARTACQUISITION_RQST 7
#define VELODYNE_STOPACQUISITION_RQST 8
#define VELODYNE_ONESHOT_RQST 9
#define VELODYNE_SETTARGETDETECTIONPARAMS_RQST 10
#define VELODYNE_GETTARGETDETECTIONPARAMS_RQST 11
#define VELODYNE_SETTARGETDETECTIONFILEOUTPUT_RQST 12
#define VELODYNE_GETTARGETDETECTIONFILEOUTPUT_RQST 13
#define VELODYNE_SETTARGETPARAMS_RQST 14
#define VELODYNE_GETTARGETPARAMS_RQST 15
#define VELODYNE_STOPTARGETDETECTION_RQST 16
#define VELODYNE_DUMPTARGET_RQST 17
#define VELODYNE_SETTARGETTRACKINGPARAMS_RQST 18
#define VELODYNE_GETTARGETTRACKINGPARAMS_RQST 19
#define VELODYNE_SETTARGETTRACKINGFILEOUTPUTPARAMS_RQST 20
#define VELODYNE_GETTARGETTRACKINGFILEOUTPUTPARAMS_RQST 21
#define VELODYNE_SETSAVEPARAMS_RQST 22
#define VELODYNE_GETSAVEPARAMS_RQST 23
#define VELODYNE_SETSAVEIM3DPARAMS_RQST 24
#define VELODYNE_GETSAVEIM3DPARAMS_RQST 25
#define VELODYNE_SAVE_RQST 26
#define VELODYNE_SAVEIM3D_RQST 27
#define VELODYNE_ABORT_RQST 28


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS velodyneClientInit (CLIENT_ID *pClientId);

STATUS velodyneClientEnd (CLIENT_ID clientId);

int velodyneAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int velodyneAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int velodyneAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS velodyneInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneInitParams *(in_initParams),
					 int replyTimeOut);

extern int velodyneInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneInitParams *(in_initParams), 
					
					int *activity, int *bilan);

extern int velodyneInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneInitParams *(in_initParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneGetInitParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetInitParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneInitParams *(out_initParams),
			       int *bilan);

int velodyneGetInitParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneInitParams *(out_initParams),
				 int *bilan);




extern STATUS velodyneSetReadModeParamsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneSaveParams *(in_readModeParams),
					 int replyTimeOut);

extern int velodyneSetReadModeParamsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneSetReadModeParamsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneSaveParams *(in_readModeParams), 
					
					int *activity, int *bilan);

extern int velodyneSetReadModeParamsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneSaveParams *(in_readModeParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneGetReadModeParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetReadModeParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneSaveParams *(out_readModeParams),
			       int *bilan);

int velodyneGetReadModeParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneSaveParams *(out_readModeParams),
				 int *bilan);




extern STATUS velodyneSetSensorToMainPlaybackRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 POM_EULER *(in_sensorToMain),
					 int replyTimeOut);

int velodyneSetSensorToMainPlaybackReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetSensorToMainPlaybackRqstAndRcv (CLIENT_ID clientId, 
				 POM_EULER *(in_sensorToMain), 
				 
				 int *bilan);




extern STATUS velodyneFOVRemoveHeadingSectorRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneFOVRemoveHeadingSectorParams *(in_fovRemoveHeadingSectorParams),
					 int replyTimeOut);

extern int velodyneFOVRemoveHeadingSectorReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneFOVRemoveHeadingSectorRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneFOVRemoveHeadingSectorParams *(in_fovRemoveHeadingSectorParams), 
					
					int *activity, int *bilan);

extern int velodyneFOVRemoveHeadingSectorRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneFOVRemoveHeadingSectorParams *(in_fovRemoveHeadingSectorParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneFOVRemoveLineRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneFOVRemoveLineParams *(in_fovRemoveLineParams),
					 int replyTimeOut);

extern int velodyneFOVRemoveLineReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneFOVRemoveLineRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneFOVRemoveLineParams *(in_fovRemoveLineParams), 
					
					int *activity, int *bilan);

extern int velodyneFOVRemoveLineRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneFOVRemoveLineParams *(in_fovRemoveLineParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneStartAcquisitionRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int velodyneStartAcquisitionReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneStartAcquisitionRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int velodyneStartAcquisitionRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS velodyneStopAcquisitionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneStopAcquisitionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneStopAcquisitionRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS velodyneOneShotRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneOneShotParams *(in_oneShotParams),
					 int replyTimeOut);

extern int velodyneOneShotReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneOneShotRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneOneShotParams *(in_oneShotParams), 
					
					int *activity, int *bilan);

extern int velodyneOneShotRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneOneShotParams *(in_oneShotParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneSetTargetDetectionParamsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneTargetDetectionParams *(in_targetDetectionParams),
					 int replyTimeOut);

extern int velodyneSetTargetDetectionParamsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneSetTargetDetectionParamsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneTargetDetectionParams *(in_targetDetectionParams), 
					
					int *activity, int *bilan);

extern int velodyneSetTargetDetectionParamsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneTargetDetectionParams *(in_targetDetectionParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneGetTargetDetectionParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetTargetDetectionParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneTargetDetectionParams *(out_targetDetectionParams),
			       int *bilan);

int velodyneGetTargetDetectionParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneTargetDetectionParams *(out_targetDetectionParams),
				 int *bilan);




extern STATUS velodyneSetTargetDetectionFileOutputRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 velodyneTargetDetectionFileOutput *(in_targetDetectionFileOutput),
					 int replyTimeOut);

int velodyneSetTargetDetectionFileOutputReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetTargetDetectionFileOutputRqstAndRcv (CLIENT_ID clientId, 
				 velodyneTargetDetectionFileOutput *(in_targetDetectionFileOutput), 
				 
				 int *bilan);




extern STATUS velodyneGetTargetDetectionFileOutputRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetTargetDetectionFileOutputReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneTargetDetectionFileOutput *(out_targetDetectionFileOutput),
			       int *bilan);

int velodyneGetTargetDetectionFileOutputRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneTargetDetectionFileOutput *(out_targetDetectionFileOutput),
				 int *bilan);




extern STATUS velodyneSetTargetParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 velodyneTargetParams *(in_targetParams),
					 int replyTimeOut);

int velodyneSetTargetParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetTargetParamsRqstAndRcv (CLIENT_ID clientId, 
				 velodyneTargetParams *(in_targetParams), 
				 
				 int *bilan);




extern STATUS velodyneGetTargetParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetTargetParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneTargetParams *(out_targetParams),
			       int *bilan);

int velodyneGetTargetParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneTargetParams *(out_targetParams),
				 int *bilan);




extern STATUS velodyneStopTargetDetectionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneStopTargetDetectionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneStopTargetDetectionRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS velodyneDumpTargetRqstSend (CLIENT_ID clientId, int *pRqstId,
					 velodyneSaveParams *(in_saveParams),
					 int replyTimeOut);

extern int velodyneDumpTargetReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneDumpTargetRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					velodyneSaveParams *(in_saveParams), 
					
					int *activity, int *bilan);

extern int velodyneDumpTargetRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					velodyneSaveParams *(in_saveParams), 
					
					int *activity,
					int *bilan);




extern STATUS velodyneSetTargetTrackingParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 velodyneTargetTrackingParams *(in_targetTrackingParams),
					 int replyTimeOut);

int velodyneSetTargetTrackingParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetTargetTrackingParamsRqstAndRcv (CLIENT_ID clientId, 
				 velodyneTargetTrackingParams *(in_targetTrackingParams), 
				 
				 int *bilan);




extern STATUS velodyneGetTargetTrackingParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetTargetTrackingParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneTargetTrackingParams *(out_targetTrackingParams),
			       int *bilan);

int velodyneGetTargetTrackingParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneTargetTrackingParams *(out_targetTrackingParams),
				 int *bilan);




extern STATUS velodyneSetTargetTrackingFileOutputParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 velodyneTargetTrackingFileOutputParams *(in_targetTrackingFileOutputParams),
					 int replyTimeOut);

int velodyneSetTargetTrackingFileOutputParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetTargetTrackingFileOutputParamsRqstAndRcv (CLIENT_ID clientId, 
				 velodyneTargetTrackingFileOutputParams *(in_targetTrackingFileOutputParams), 
				 
				 int *bilan);




extern STATUS velodyneGetTargetTrackingFileOutputParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetTargetTrackingFileOutputParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneTargetTrackingFileOutputParams *(out_targetTrackingFileOutputParams),
			       int *bilan);

int velodyneGetTargetTrackingFileOutputParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneTargetTrackingFileOutputParams *(out_targetTrackingFileOutputParams),
				 int *bilan);




extern STATUS velodyneSetSaveParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 velodyneSaveParams *(in_saveParams),
					 int replyTimeOut);

int velodyneSetSaveParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetSaveParamsRqstAndRcv (CLIENT_ID clientId, 
				 velodyneSaveParams *(in_saveParams), 
				 
				 int *bilan);




extern STATUS velodyneGetSaveParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetSaveParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneSaveParams *(out_saveParams),
			       int *bilan);

int velodyneGetSaveParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneSaveParams *(out_saveParams),
				 int *bilan);




extern STATUS velodyneSetSaveIm3DParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 velodyneSaveParams *(in_saveIm3DParams),
					 int replyTimeOut);

int velodyneSetSaveIm3DParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int velodyneSetSaveIm3DParamsRqstAndRcv (CLIENT_ID clientId, 
				 velodyneSaveParams *(in_saveIm3DParams), 
				 
				 int *bilan);




extern STATUS velodyneGetSaveIm3DParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int velodyneGetSaveIm3DParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       velodyneSaveParams *(out_saveIm3DParams),
			       int *bilan);

int velodyneGetSaveIm3DParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 velodyneSaveParams *(out_saveIm3DParams),
				 int *bilan);




extern STATUS velodyneSaveRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int velodyneSaveReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneSaveRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int velodyneSaveRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS velodyneSaveIm3DRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int velodyneSaveIm3DReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int velodyneSaveIm3DRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int velodyneSaveIm3DRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* velodyne_MSG_LIB_H */

